import * as helpers from './helpers';


class Parallax {
	constructor(element) {
		this.element = element;
		this.options = Parallax.defaults;	
		this.parallaxImages = [];	
		this.init();
	}

	init() {
		const _Parallax = this,
			images = _Parallax.element.getElementsByTagName('img');

		for (let i = 0; i < images.length; i++) {
			let constraint = _Parallax.options.constraint,
				scale = _Parallax.options.scale,
				options = images[i].getAttribute('data-options');

			if (options) {
				options = helpers.toObject(options);
				constraint = options.constraint ? options.constraint : constraint,
				scale = options.scale ? options.scale : scale;
			}

			_Parallax.parallaxImages.push({
				imageElement: images[i],
				constraint: parseFloat(constraint),
				scale: parseFloat(scale)
			});
		}
		
		if (window.matchMedia("(min-width: 400px)").matches) {
			const intervalID = setInterval(() => {
				_Parallax.updateImages(this);
			}, 10);
		}
	}

	updateImages(_Parallax) {

		window.requestAnimationFrame(() => {
			const docHeight = document.body.clientHeight,
				windowHeight = window.innerHeight,
				maxSt = docHeight - windowHeight,
				st = window.pageYOffset,
				scrollPercent = st / maxSt * 100,
				translateBy = windowHeight / 100 * scrollPercent;

			for (let i = 0; i < _Parallax.parallaxImages.length; i++) {
				let { imageElement, constraint, scale } = _Parallax.parallaxImages[i];

        		_Parallax.writeTransformStyle(imageElement, parseInt(translateBy / constraint), scale);
			}
		});
	}

	writeTransformStyle(element, translate, scale) {
		element.style.WebkitTransform = `translateY(-${translate}px) scale(${scale})`;
		element.style.MozTransform = `translateY(-${translate}px) scale(${scale})`;
		element.style.msTransform = `translateY(-${translate}px) scale(${scale})`;
		element.style.OTransform = `translateY(-${translate}px) scale(${scale})`;
		element.style.transform = `translateY(-${translate}px) scale(${scale})`;
	}
}

Parallax.defaults = {
	constraint: 1.5,
	scale: 1
}

export default Parallax;
